#pragma once
#ifndef ClassParticuleEngine
#define ClassParticuleEngine
#include "Announcement.h"
#include "MonochromeLib.h"
#include "List.h"
#include "usefull.h"
#include "Ressources.h"

enum Tag
{
    Untagged = 0,
    Respawn = 1,
    Finish = 2,
    EditorOnly = 3,
    MainCamera = 4,
    Player = 5,
    GameController = 6
};

enum Layer
{
    Default = 0,
    TransparentFX = 1,
    IgnoreRaycast = 2,
    Water = 3,
    UI = 4
};

class Vector2 {
    //https://docs.unity3d.com/ScriptReference/Vector2.html
public:
    float x;
    float y;
    Vector2() {
        this->x = 0;
        this->y = 0;
    }
    Vector2(float x, float y) {
        this->x = x;
        this->y = y;
    };
    void Set(float x, float y) {
        this->x = x;
        this->y = y;
    };
    void Set(Vector2 vect) {
        this->x = vect.x;
        this->y = vect.y;
    };

    bool operator==(const Vector2& other) {
        return this->x == other.x && this->y == other.y;
    }

    bool operator!=(const Vector2& other) {
        return !(this->x == other.x && this->y == other.y);
    }

    Vector2 operator+(const Vector2& other) {
        return Vector2(this->x + other.x, this->y + other.y);
    }

    Vector2 operator-(const Vector2& other) {
        return Vector2(this->x - other.x, this->y - other.y);
    }

    Vector2 operator*(const Vector2& other) {
        return Vector2(this->x * other.x, this->y * other.y);
    }

    Vector2 operator/(const Vector2& other) {
        return Vector2(this->x / other.x, this->y / other.y);
    }
};

class Quaternion {
    //https://docs.unity3d.com/ScriptReference/Quaternion.html
public:

};

class Matrix4x4 {
    //https://docs.unity3d.com/ScriptReference/Matrix4x4.html
public:

};

class Object {
    //https://docs.unity3d.com/ScriptReference/Object.html
public:
    Object(const char* name, const char* UUID=NULL) {
        this->name = (unsigned char*)name;
        this->ID = (unsigned char*)UUID;
    };
    //hideFlags c'est pour l'diteur donc il n'est pas prsent
    unsigned char* name;

    unsigned char* GetInstanceID() {
        return ID;
    };
    unsigned char* ToString() {
        return name;
    };
    virtual void Destroy() {}
    virtual void DestroyImmediate() {}
    virtual void DontDestroyOnLoad() {}
    virtual void FindObjectOfType() {}
    virtual void FindObjectsOfType() {}
    virtual void Instantiate() {}

    // Overload operator
    bool operator==(const Object& obj) {
        return this->ID == obj.ID;
    }

    bool operator!=(const Object& obj) {
        return this->ID != obj.ID;
    }
private:
    unsigned char* ID;
};

class Component : public Object {
    //https://docs.unity3d.com/ScriptReference/Component.html
public:
    char* tag;
    GameObject* gameObject;
    Transform* transform;

    Component(const char* name, GameObject* gameObject ,const char* UUID = NULL) : Object(name, UUID)
    {
        this->gameObject = gameObject;
    };

    void BroadcastMessage();
    void CompareTag();
    void GetComponent();
    void GetComponentInChildren();
    void GetComponentInParent();
    void GetComponents();
    void GetComponentsInChildren();
    void GetComponentsInParent();
    void SendMessage();
    void SendMessageUpwards();
    void TryGetComponent();

    virtual void Awake() {}
    virtual void FixedUpdate() {}
    virtual void LateUpdate() {}
    virtual void OnAnimatorIK() {}
    virtual void OnAnimatorMove() {}
    virtual void OnApplicationFocus() {}
    virtual void OnApplicationPause() {}
    virtual void OnApplicationQuit() {}
    virtual void OnAudioFilterRead() {}
    virtual void OnBecameInvisible() {}
    virtual void OnBecameVisible() {}
    virtual void OnCollisionEnter() {}
    virtual void OnCollisionEnter2D() {}
    virtual void OnCollisionExit() {}
    virtual void OnCollisionExit2D() {}
    virtual void OnCollisionStay() {}
    virtual void OnCollisionStay2D() {}
    virtual void OnConnectedToServer() {}
    virtual void OnControllerColliderHit() {}
    virtual void OnDestroy() {}
    virtual void OnDisable() {}
    virtual void OnDisconnectedFromServer() {}
    virtual void OnDrawGizmos() {}
    virtual void OnDrawGizmosSelected() {}
    virtual void OnEnable() {}
    virtual void OnFailedToConnect() {}
    virtual void OnFailedToConnectToMasterServer() {}
    virtual void OnGUI() {}
    virtual void OnJointBreak() {}
    virtual void OnJointBreak2D() {}
    virtual void OnMasterServerEvent() {}
    virtual void OnMouseDown() {}
    virtual void OnMouseDrag() {}
    virtual void OnMouseEnter() {}
    virtual void OnMouseExit() {}
    virtual void OnMouseOver() {}
    virtual void OnMouseUp() {}
    virtual void OnMouseUpAsButton() {}
    virtual void OnNetworkInstantiate() {}
    virtual void OnParticleCollision() {}
    virtual void OnParticleSystemStopped() {}
    virtual void OnParticleTrigger() {}
    virtual void OnParticleUpdateJobScheduled() {}
    virtual void OnPlayerConnected() {}
    virtual void OnPlayerDisconnected() {}
    virtual void OnPostRender() {}
    virtual void OnPreCull() {}
    virtual void OnPreRender() {}
    virtual void OnRenderImage() {}
    virtual void OnRenderObject() {}
    virtual void OnSerializeNetworkView() {}
    virtual void OnServerInitialized() {}
    virtual void OnTransformChildrenChanged() {}
    virtual void OnTransformParentChanged() {}
    virtual void OnTriggerEnter() {}
    virtual void OnTriggerEnter2D() {}
    virtual void OnTriggerExit() {}
    virtual void OnTriggerExit2D() {}
    virtual void OnTriggerStay() {}
    virtual void OnTriggerStay2D() {}
    virtual void OnValidate() {}
    virtual void OnWillRenderObject() {}
    virtual void Reset() {}
    virtual void Start() {}
    virtual void Update() {}
};
class Transform : public Component {
    //https://docs.unity3d.com/ScriptReference/Transform.html
public:
    List<Transform*> childs;
    int childCount;
    Vector2 eulerAngles;
    //Vector2 forward;
    bool hasChanged;
    int hierarchyCapacity;
    int hierarchyCount;
    Vector2 localEulerAngles;
    Vector2 localPosition;
    Quaternion* localRotation;
    Vector2 localScale;
    Matrix4x4* localToWorldMatrix;
    Vector2 lossyScale;
    Transform* parent;
    Vector2 position;
    //Vector2 right;
    Transform* root;
    Quaternion* rotation;
    //Vector2 up;
    Matrix4x4* worldToLocalMatrix;

    Transform(GameObject* gameObject, const char* UUID = NULL, const char* name = "Transform") : Component(name,gameObject,UUID){
        childCount = 0;
        eulerAngles = Vector2();
        //forward = None
        hasChanged = NULL;
        hierarchyCapacity = NULL;
        hierarchyCount = NULL;
        localEulerAngles = Vector2();
        localPosition = Vector2();
        localRotation = NULL;
        localScale = Vector2(1,1);
        localToWorldMatrix = NULL;
        lossyScale = Vector2(1,1);
        parent = NULL;
        //childs = []
        position = Vector2();
        //self.right = None
        root = NULL;
        rotation = NULL;
        //self.up = None
        worldToLocalMatrix = NULL;
    };

    void SetParent(Transform* transform) {
        if (parent != NULL) {
            parent->childs.Remove(this);
        }
        transform->childs.Add(this);
        parent = transform;
    }

    void Update() {
        childCount = childs.Count;
        if (parent == NULL) {

        }
        else
        {
            position.Set(localPosition + parent->position);
        }
    }
};


class Behaviour : public Component {
    //https://docs.unity3d.com/ScriptReference/Behaviour.html
public:

    bool enabled;
    bool isActiveAndEnabled;
    Behaviour(const char* name, GameObject* gameObject, const char* UUID = NULL) : Component(name,gameObject, UUID) {
        enabled = true;
        isActiveAndEnabled = true;
    };
};

/*
enum ScaleMode
{
    //https://docs.unity3d.com/ScriptReference/ScaleMode.html
    StretchToFill,
    ScaleAndCrop,
    ScaleToFit,
};
class CallbackEventHandler{
    //https://docs.unity3d.com/ScriptReference/UIElements.CallbackEventHandler.html

};

class Focusable : public CallbackEventHandler {
    //https://docs.unity3d.com/ScriptReference/UIElements.Focusable.html

};

class VisualElement : public Focusable {
    //https://docs.unity3d.com/ScriptReference/UIElements.VisualElement.html

};
*/


enum TextureDimension
{
    Unknown,
    None,
    Any,
    Tex2D,
    Tex3D,
    Cube,
    Tex2DArray,
    CubeArray
};

enum FilterMode
{
    Point,
    Bilinear,
    Trilinear
};

class Texture : public Object {
    //https://docs.unity3d.com/ScriptReference/Texture.html
public:
    Texture() : Object("None", NULL) {
        const unsigned char None[] = { 0x0 };
        textureData = (unsigned char*)None;
        this->width = 0;
        this->height = 0;
    };
    Texture(const char* name, int width, int height, const unsigned char* Data, const char* UUID = NULL) : Object(name, UUID) {
        textureData = (unsigned char*)Data;
        this->width = width;
        this->height = height;
    };
    unsigned char* textureData;
    /*
    bool allowThreadedTextureCreation;
    int currentTextureMemory;
    int desiredTextureMemory;
    int GenerateAllMips;
    int nonStreamingTextureCount;
    int nonStreamingTextureMemory;
    int streamingMipmapUploadCount;
    int streamingRendererCount;
    int streamingTextureCount;
    bool streamingTextureDiscardUnusedMips;
    bool streamingTextureForceLoadAll;
    int streamingTextureLoadingCount;
    int streamingTexturePendingLoadCount;
    int targetTextureMemory;
    int totalTextureMemory;*/

    //int anisoLevel;
    TextureDimension dimension;
    FilterMode filterMode;
    //graphicsFormat;//https://docs.unity3d.com/ScriptReference/Experimental.Rendering.GraphicsFormat.html
    int height;
    //imageContentsHash;//https://docs.unity3d.com/ScriptReference/Hash128.html
    bool isReadable;
    //float mipMapBias;
    //int mipmapCount;
    //int updateCount;
    int width;
    //wrapMode;//https://docs.unity3d.com/ScriptReference/TextureWrapMode.html
    //wrapModeU;
    //wrapModeV;
    //wrapModeW;

    


};

class MonoBehaviour : public Behaviour {
    //https://docs.unity3d.com/ScriptReference/MonoBehaviour.html
public:
    //runInEditMode c'est pour l'diteur donc il n'est pas prsent
    bool useGUILayout;

    MonoBehaviour(const char* name, GameObject* gameObject, const char* UUID = NULL) : Behaviour(name,gameObject, UUID) {
        useGUILayout = true;
    };

    void CancelInvoke();
    void Invoke();
    void InvokeRepeating();
    void IsInvoking();
    void StartCoroutine();
    void StopAllCoroutines();
    void StopCoroutine();
    //print c'est pour l'diteur donc il n'est pas prsent
};


class GameObject : public Object {
    //https://docs.unity3d.com/ScriptReference/GameObject.html
private:
    List<Component*> ListOfComponent;
public:
    bool activeInHierarchy;
    bool activeSelf;
    bool isStatic;
    Layer layer;
    Scene* scene;
    long sceneCullingMask;
    Tag tag;
    Transform* transform;

    GameObject(Scene* scene,const char* name, const char* UUID = NULL) : Object(name, UUID)
    {
        this->scene = scene;
        this->transform = new Transform(this);
        activeInHierarchy = true;
        activeSelf = true;
        isStatic = false;
        layer = Default;
        sceneCullingMask = NULL;
        tag = Untagged;
        //ListOfComponent.Add(transform);
    };

    void Update() {
        this->transform->Update();
        for (int i = 0; i < ListOfComponent.Count; i++)
        {
            ListOfComponent[i]->Update();
        }
    };

    void Start() {
        this->transform->Start();
        for (int i = 0; i < ListOfComponent.Count; i++)
        {
            ListOfComponent[i]->Start();
        }
    };

    void AddComponent(Component* component) {
        ListOfComponent.Add(component);
    };
    void BroadcastMessage();
    void CompareTag();
    Component* GetComponent(const char* name) {
        for (int i = 0; i < ListOfComponent.Count; i++)
        {
            if (ListOfComponent[i]->name == (unsigned char*)name)
                return ListOfComponent[i];
        }
        return NULL;
    };
    void GetComponentInChildren();
    void GetComponentInParent();
    void GetComponents();
    void GetComponentsInChildren();
    void GetComponentsInParent();
    void SendMessage();
    void SendMessageUpwards();
    void SetActive();
    void TryGetComponent();

    static void CreatePrimitive();
    static void Find();
    static void FindGameObjectsWithTag();
    static void FindWithTag();
};


class Scene {
    //https://docs.unity3d.com/ScriptReference/SceneManagement.Scene.html
private:
    List<GameObject*> AllGameObject;
public:
    void GetRootGameObjects();
    bool IsValid();

    void AddGameObject(GameObject* gObj) {
        AllGameObject.Add(gObj);
    };

    void Update() {
        for (int i = 0; i < AllGameObject.Count; i++)
        {
            AllGameObject[i]->Update();
        }
    };

    void Start() {
        for (int i = 0; i < AllGameObject.Count; i++)
        {
            AllGameObject[i]->Start();
        }
    };

    int buildIndex;
    bool isDirty;
    bool isLoaded;
    char* name;
    //char* path;
    int rootCount;

    List<Camera*> AllCameras;
};

class Camera : public Behaviour {
    //https://docs.unity3d.com/ScriptReference/Camera.html
public:
    Camera(GameObject* gameObject, const char* UUID = NULL) : Behaviour("Camera", gameObject, UUID) {
        gameObject->scene->AllCameras.Add(this);
    }
};

class Image : MonoBehaviour { //: public VisualElement {
    //https://docs.unity3d.com/ScriptReference/UIElements.Image.html
public:
    //unsigned char* ussClassName;
    Texture* image;
    //scaleMode
    //sourceRect
    //tintColor
    //uv
    //vectorImage

    Image(GameObject* gameObject, Texture* image, const char* UUID = NULL) : MonoBehaviour("Image", gameObject, UUID) {
        this->image = image;
    };

    void Update() {
        float posX = gameObject->transform->position.x;
        float posY = gameObject->transform->position.y;
        float camX = gameObject->scene->AllCameras[0]->gameObject->transform->position.x;
        float camY = gameObject->scene->AllCameras[0]->gameObject->transform->position.y;
        if (posX - camX + image->height > 0 && posX - camX < 128 && posY - camY + image->height>0 && posY - camY < 64)
            ML_bmp_or_cl((const unsigned char*)image->textureData, (int)(posX - camX), (int)(posY - camY), image->width, image->height);
    };
};

class Sprite : MonoBehaviour { //: public VisualElement {
    //https://docs.unity3d.com/ScriptReference/UIElements.Image.html
public:

    Texture* image;


    Sprite(GameObject* gameObject, Texture* image, const char* UUID = NULL) : MonoBehaviour("Sprite", gameObject, UUID) {
        this->image = image;
    };

    void Update() {
        float posX = gameObject->transform->position.x;
        float posY = gameObject->transform->position.y;
        float camX = gameObject->scene->AllCameras[0]->gameObject->transform->position.x;
        float camY = gameObject->scene->AllCameras[0]->gameObject->transform->position.y;
        if (posX - camX + image->height > 0 && posX - camX < 128 && posY - camY + image->height>0 && posY - camY < 64)
            ML_bmp_or_cl((const unsigned char*)image->textureData, (int)(posX - camX), (int)(posY - camY), image->width, image->height);
    };
};


class Rigidbody : MonoBehaviour {
private:
    
public:
    float Mass;
    bool UseGravity;
    bool IsKinematic;
    Vector2 velocity;

    Rigidbody(GameObject* gameObject, float Mass, bool UseGravity, bool IsKinematic, const char* UUID = NULL) : MonoBehaviour("Rigidbody", gameObject, UUID) {
        this->Mass = Mass;
        this->UseGravity = UseGravity;
        this->IsKinematic = IsKinematic;
        this->velocity = Vector2();

    };

    void Start() {
        this->velocity.Set(0,0);
    }
    
};


class Collider2D : MonoBehaviour {
    //https://docs.unity3d.com/ScriptReference/Collider2D.html
public:
    
};

class BoxCollider2D : Collider2D {
    //https://docs.unity3d.com/ScriptReference/BoxCollider2D.html
public:
    
};

class Text : MonoBehaviour {

public:
    unsigned char* text;

    Text(GameObject* gameObject, unsigned char* text, const char* UUID = NULL) : MonoBehaviour("Text", gameObject, UUID) {
        this->text = text;

    };

    void Update() {
        float posX = gameObject->transform->position.x;
        float posY = gameObject->transform->position.y;
        float camX = gameObject->scene->AllCameras[0]->gameObject->transform->position.x;
        float camY = gameObject->scene->AllCameras[0]->gameObject->transform->position.y;
        PrintMini((int)(posX - camX), (int)(posY - camY), (unsigned char*)this->text, MINI_OVER);
    }


};

class PlayerController : MonoBehaviour {
private:
    Sprite* sprite;
    int frame;
public:
    Texture* right1;
    Texture* right2;
    Texture* left1;
    Texture* left2;

    PlayerController(GameObject* gameObject, Texture* right1, Texture* right2, Texture* left1, Texture* left2, const char* UUID = NULL) : MonoBehaviour("PlayerController", gameObject, UUID) {
        this->right1 = right1;
        this->right2 = right2;
        this->left1 = left1;
        this->left2 = left2;
        this->frame = 0;

    };

    void Start() {
        sprite = (Sprite*)this->gameObject->GetComponent("Sprite");
    }
    void Update() {
        if (IsKeyDown(KEY_CTRL_RIGHT)) {
            this->gameObject->transform->position.x += 3;
            if (frame == 0) {
                sprite->image = left1;
                frame += 1;
            }
            else
            {
                sprite->image = left2;
                frame = 0;
            }
        }
        else {
            if (IsKeyDown(KEY_CTRL_LEFT)) {
                this->gameObject->transform->position.x -= 3;
                if (frame == 0) {
                    sprite->image = right1;
                    frame += 1;
                }
                else
                {
                    sprite->image = right2;
                    frame = 0;
                }
            }

        }

    }

};



class SceneManager {
    //https://docs.unity3d.com/ScriptReference/SceneManagement.SceneManager.html
public:
    int sceneCount;
    static int sceneCountInBuildSettings;

    //Static Methods
    static void CreateScene();
    static void GetActiveScene();
    static void GetSceneAt();
    static void GetSceneByBuildIndex();
    static void GetSceneByName();
    static void GetSceneByPath();
    void LoadScene(int index) {
        AllSceneLoaded.Clear();
        AllSceneLoaded.Add(GetSceneInBuild(index));
    };
    void LoadScene(unsigned char* name) {
        AllSceneLoaded.Clear();
        AllSceneLoaded.Add(GetSceneInBuild(name));
    };
    static void LoadSceneAsync();
    static void MergeScenes();
    static void MoveGameObjectToScene();
    static void SetActiveScene();
    static void UnloadSceneAsync();

    //Events
    static void activeSceneChanged();
    static void sceneLoaded();
    static void sceneUnloaded();

    void UpdateScene() {
        for (int i = 0; i < AllSceneLoaded.Count; i++)
        {
            AllSceneLoaded[i]->Update();
        }
    };

    void StartScene() {
        for (int i = 0; i < AllSceneLoaded.Count; i++)
        {
            AllSceneLoaded[i]->Start();
        }
    }
private:
    List<Scene*> AllSceneLoaded;


    Scene* GetSceneInBuild(int index) {
        Scene* newScene = new Scene();

        Texture* Texture_UUID_01a26007_e996_4bc5_9281_05cd12ce3811= new Texture("Texture",24,24,UUID_01a26007_e996_4bc5_9281_05cd12ce3811);
Texture* Texture_UUID_1658cd70_83f6_4444_a246_013cb907e327= new Texture("Texture",24,24,UUID_1658cd70_83f6_4444_a246_013cb907e327);
Texture* Texture_UUID_26f43cc3_7626_414d_95ec_0997432b9234= new Texture("Texture",24,24,UUID_26f43cc3_7626_414d_95ec_0997432b9234);
Texture* Texture_UUID_c22f2a37_0e4c_41cc_948c_0829ff4befa9= new Texture("Texture",24,24,UUID_c22f2a37_0e4c_41cc_948c_0829ff4befa9);
Texture* Texture_UUID_cafc0536_f479_486c_a626_d85fc0d30eff= new Texture("Texture",101,51,UUID_cafc0536_f479_486c_a626_d85fc0d30eff);
if (index == 0){
Text* UUID_c8ea7091_a614_4b24_8143_c3fd9bfdc2b4;

Sprite* UUID_adfedbd5_6827_46f9_9554_c603e0f13649;

Text* UUID_1453337a_3e75_4d14_b44b_a24a1390ea31;

Text* UUID_3271dabb_2ba3_4884_8c06_7ac2ef4f8786;

Camera* UUID_b9a86b88_c948_45f2_8b15_0c62cc8c7da8;

PlayerController* UUID_a8d08dfe_cb39_4c6f_b628_9c85b711fad6;
Sprite* UUID_12a8d5ae_2ced_46e4_9b98_4e7db0e8381f;

GameObject* UUID_c0c27648_d49e_421a_9118_01ea51fc8e04= new GameObject(newScene, "GameObject (1)","UUID_c0c27648_d49e_421a_9118_01ea51fc8e04");
UUID_c0c27648_d49e_421a_9118_01ea51fc8e04->transform->position.Set(197,109);
UUID_c0c27648_d49e_421a_9118_01ea51fc8e04->transform->localPosition.Set(197,109);
newScene->AddGameObject(UUID_c0c27648_d49e_421a_9118_01ea51fc8e04);
GameObject* UUID_487fc953_b170_4aaf_836d_e77134c20b5e= new GameObject(newScene, "GameObject","UUID_487fc953_b170_4aaf_836d_e77134c20b5e");
UUID_487fc953_b170_4aaf_836d_e77134c20b5e->transform->position.Set(150,77);
UUID_487fc953_b170_4aaf_836d_e77134c20b5e->transform->localPosition.Set(-47,-32);
UUID_487fc953_b170_4aaf_836d_e77134c20b5e->transform->SetParent(UUID_c0c27648_d49e_421a_9118_01ea51fc8e04->transform);newScene->AddGameObject(UUID_487fc953_b170_4aaf_836d_e77134c20b5e);
GameObject* UUID_ab250bc7_e48d_4ea1_9ac6_ca61c3d3dd06= new GameObject(newScene, "Text","UUID_ab250bc7_e48d_4ea1_9ac6_ca61c3d3dd06");
UUID_ab250bc7_e48d_4ea1_9ac6_ca61c3d3dd06->transform->position.Set(154.0,78.0);
UUID_ab250bc7_e48d_4ea1_9ac6_ca61c3d3dd06->transform->localPosition.Set(154.0,78.0);
newScene->AddGameObject(UUID_ab250bc7_e48d_4ea1_9ac6_ca61c3d3dd06);
GameObject* UUID_0c42c1f7_8070_43e1_9fad_29f16e964bcf= new GameObject(newScene, "Text2","UUID_0c42c1f7_8070_43e1_9fad_29f16e964bcf");
UUID_0c42c1f7_8070_43e1_9fad_29f16e964bcf->transform->position.Set(154,85);
UUID_0c42c1f7_8070_43e1_9fad_29f16e964bcf->transform->localPosition.Set(154,85);
newScene->AddGameObject(UUID_0c42c1f7_8070_43e1_9fad_29f16e964bcf);
GameObject* UUID_79e301ed_88c1_447d_90ad_f915ae66e2ff= new GameObject(newScene, "GameObject (2)","UUID_79e301ed_88c1_447d_90ad_f915ae66e2ff");
UUID_79e301ed_88c1_447d_90ad_f915ae66e2ff->transform->position.Set(286.0,83.0);
UUID_79e301ed_88c1_447d_90ad_f915ae66e2ff->transform->localPosition.Set(286.0,83.0);
newScene->AddGameObject(UUID_79e301ed_88c1_447d_90ad_f915ae66e2ff);
GameObject* UUID_93f419de_2456_426e_9e0b_5f4b0099c7c3= new GameObject(newScene, "Text3","UUID_93f419de_2456_426e_9e0b_5f4b0099c7c3");
UUID_93f419de_2456_426e_9e0b_5f4b0099c7c3->transform->position.Set(150.0,93.0);
UUID_93f419de_2456_426e_9e0b_5f4b0099c7c3->transform->localPosition.Set(150.0,93.0);
newScene->AddGameObject(UUID_93f419de_2456_426e_9e0b_5f4b0099c7c3);

UUID_12a8d5ae_2ced_46e4_9b98_4e7db0e8381f = new Sprite(UUID_c0c27648_d49e_421a_9118_01ea51fc8e04,Texture_UUID_1658cd70_83f6_4444_a246_013cb907e327,"UUID_12a8d5ae_2ced_46e4_9b98_4e7db0e8381f");
UUID_c0c27648_d49e_421a_9118_01ea51fc8e04->AddComponent((Component*)UUID_12a8d5ae_2ced_46e4_9b98_4e7db0e8381f);
UUID_a8d08dfe_cb39_4c6f_b628_9c85b711fad6 = new PlayerController(UUID_c0c27648_d49e_421a_9118_01ea51fc8e04,Texture_UUID_c22f2a37_0e4c_41cc_948c_0829ff4befa9,Texture_UUID_26f43cc3_7626_414d_95ec_0997432b9234,Texture_UUID_01a26007_e996_4bc5_9281_05cd12ce3811,Texture_UUID_1658cd70_83f6_4444_a246_013cb907e327,"UUID_a8d08dfe_cb39_4c6f_b628_9c85b711fad6");
UUID_c0c27648_d49e_421a_9118_01ea51fc8e04->AddComponent((Component*)UUID_a8d08dfe_cb39_4c6f_b628_9c85b711fad6);

UUID_b9a86b88_c948_45f2_8b15_0c62cc8c7da8 = new Camera(UUID_487fc953_b170_4aaf_836d_e77134c20b5e,"UUID_b9a86b88_c948_45f2_8b15_0c62cc8c7da8");
UUID_487fc953_b170_4aaf_836d_e77134c20b5e->AddComponent((Component*)UUID_b9a86b88_c948_45f2_8b15_0c62cc8c7da8);

UUID_3271dabb_2ba3_4884_8c06_7ac2ef4f8786 = new Text(UUID_ab250bc7_e48d_4ea1_9ac6_ca61c3d3dd06,(unsigned char*)"Bonjour, ceci est un test.","UUID_3271dabb_2ba3_4884_8c06_7ac2ef4f8786");
UUID_ab250bc7_e48d_4ea1_9ac6_ca61c3d3dd06->AddComponent((Component*)UUID_3271dabb_2ba3_4884_8c06_7ac2ef4f8786);

UUID_1453337a_3e75_4d14_b44b_a24a1390ea31 = new Text(UUID_0c42c1f7_8070_43e1_9fad_29f16e964bcf,(unsigned char*)"Ce test a ete fait avec :","UUID_1453337a_3e75_4d14_b44b_a24a1390ea31");
UUID_0c42c1f7_8070_43e1_9fad_29f16e964bcf->AddComponent((Component*)UUID_1453337a_3e75_4d14_b44b_a24a1390ea31);

UUID_adfedbd5_6827_46f9_9554_c603e0f13649 = new Sprite(UUID_79e301ed_88c1_447d_90ad_f915ae66e2ff,Texture_UUID_cafc0536_f479_486c_a626_d85fc0d30eff,"UUID_adfedbd5_6827_46f9_9554_c603e0f13649");
UUID_79e301ed_88c1_447d_90ad_f915ae66e2ff->AddComponent((Component*)UUID_adfedbd5_6827_46f9_9554_c603e0f13649);

UUID_c8ea7091_a614_4b24_8143_c3fd9bfdc2b4 = new Text(UUID_93f419de_2456_426e_9e0b_5f4b0099c7c3,(unsigned char*)"Aller a droite pour voir le logo","UUID_c8ea7091_a614_4b24_8143_c3fd9bfdc2b4");
UUID_93f419de_2456_426e_9e0b_5f4b0099c7c3->AddComponent((Component*)UUID_c8ea7091_a614_4b24_8143_c3fd9bfdc2b4);

}

        return newScene;

    }

    Scene* GetSceneInBuild(unsigned char* name) {
        unsigned char* AllName[] = {"Main"};
        int count = 0;
        for (int i = 0; i < count; i++)
        {
            if (name == AllName[i]) {
                return GetSceneInBuild(i);
            }
        }
        return NULL;
    }
};


#endif